Struct actix_web::cookie::time::format_description::well_known::iso8601::Iso8601
source · [−]pub struct Iso8601<const CONFIG: u128 = _>;Expand description
The format described in ISO 8601.
This implementation is of ISO 8601-1:2019. It may not be compatible with other versions.
The const parameter CONFIG must be a value that was returned by Config::encode.
Passing any other value is unspecified behavior.
Example: 1997-11-21T09:55:06.000000000-06:00
Examples
assert_eq!(
datetime!(1997-11-12 9:55:06 -6:00).format(&Iso8601::DEFAULT)?,
"1997-11-12T09:55:06.000000000-06:00"
);Implementations
sourceimpl Iso8601<_>
impl Iso8601<_>
sourcepub const DEFAULT: Iso8601<_> = Self
pub const DEFAULT: Iso8601<_> = Self
An Iso8601 with the default configuration.
The following is the default behavior:
- The configuration can be used for both formatting and parsing.
- The date, time, and UTC offset are all formatted.
- Separators (such as
-and:) are included. - The year contains four digits, such that the year must be between 0 and 9999.
- The date uses the calendar format.
- The time has precision to the second and nine decimal digits.
- The UTC offset has precision to the minute.
If you need different behavior, use Config::DEFAULT and Config’s methods to create
a custom configuration.